/* pebble-js-app.js for Metar Watchface v1.0, John McManigle, 17 Feb 2014
 * I appreciate attribution or links to http://www.oxfordechoes.com/pebble-fonts/
 * but you are free to use this for any purpose.  No warranties, express or implied.
 * Not for flight planning or navigation.
 */


function fetchWeather(latitude, longitude) {
  var response;
  var req = new XMLHttpRequest();
  var url = "http://www.feathersquare.com/metar/nearest.php?" + "lat=" + latitude + "&lon=" + longitude;
  console.log(url);
  req.open('GET', url, true);
  req.onload = function(e) {
    //console.log("req.onload; req.readyState="+req.readyState+"; req.status="+req.status);
    if (req.readyState == 4) {
      if(req.status == 200) {
        var lines = req.responseText.split("\n");
        var offset = parseInt(new Date().getTimezoneOffset() * 60);
        /*
        console.log("station_name: "+lines[0]);
        console.log("station_loc:  "+lines[1]);
        console.log("timestamp:    "+lines[2]);
        console.log("flight_rules: "+lines[3]);
        console.log("wind_line:    "+lines[4]);
        console.log("sky_line:     "+lines[5]);
        console.log("wx_line:      "+lines[6]);
        console.log("offset:       "+offset);
        */
        
        Pebble.sendAppMessage({
            "station_name":lines[0],
            "station_loc":lines[1],
            "timestamp":parseInt(lines[2],10),
            "flight_rules":lines[3],
            "wind_line":lines[4],
            "sky_line":lines[5],
            "wx_line":lines[6],
            "timezone_offset":offset },
            function(e) { /*
                console.log("Successfully delivered message with transactionId="
                  + e.data.transactionId);
              */},
            function(e) {
                console.log("Unable to deliver message with transactionId="
                  + e.data.transactionId
                  + " Error is: " + e.error.message);
              });
      } else {
        console.log("Error: " + req.status);
      }
    }
  }
  req.send(null);
}

function locationSuccess(pos) {
  var coordinates = pos.coords;
  fetchWeather(coordinates.latitude, coordinates.longitude);
}

function locationError(err) {
  console.warn('location error (' + err.code + '): ' + err.message);
}

var locationOptions = { "timeout": 60000, "maximumAge": 300000 }; 

Pebble.addEventListener("appmessage",
                        function(e) {
                          navigator.geolocation.getCurrentPosition(locationSuccess,
                                                            locationError, locationOptions); });
